pyzmq: Python bindings for the zeromq networking library
========================================================

Description
-----------

Python bindings for the zeromq networking library.

License
-------

LGPLv3+


Upstream Contact
----------------

http://www.zeromq.org

Dependencies
------------

-  Python
-  Cython
-  zeromq


Special Update/Build Instructions
---------------------------------

None.
